%%%-------------------------------------------------------------------
%%% @author Piotr Duleba
%%% @copyright (C) 2020 ACK CYFRONET AGH
%%% This software is released under the MIT license
%%% cited in 'LICENSE.txt'.
%%% @end
%%%-------------------------------------------------------------------
%%% @doc
%%% This file provides functions for making rpc calls to Onepanel Nodes for use during tests.
%%% @end
%%%-------------------------------------------------------------------
-module(panel_test_rpc).
-author("Piotr Duleba").

-include_lib("ctool/include/test/test_utils.hrl").

%% API
-export([
    get_op_worker_nodes/1,
    get_cert_chain_ders/1,
    get_cluster_id/1,
    create_invite_token/1
]).

-define(CALL(NodeSelector, Args), test_rpc:call(onepanel, NodeSelector, ?FUNCTION_NAME, Args)).


%%%===================================================================
%%% API functions
%%%===================================================================


-spec get_op_worker_nodes(oct_background:node_selector()) -> [node()].
get_op_worker_nodes(NodeSelector) ->
    ?CALL(NodeSelector, []).


-spec get_cert_chain_ders(oct_background:node_selector()) -> [public_key:der_encoded()].
get_cert_chain_ders(NodeSelector) ->
    ?CALL(NodeSelector, []).


-spec get_cluster_id(oct_background:node_selector()) -> binary().
get_cluster_id(NodeSelector) ->
    ?CALL(NodeSelector, []).


-spec create_invite_token(oct_background:node_selector()) -> binary().
create_invite_token(NodeSelector) ->
    {ok, Token} = ?assertMatch({ok, _}, ?CALL(NodeSelector, [])),
    Token.
